submission 515768
Weyland Joyner · python · License unknown
Use it
Vendorable · source mirrored · license unknownView source →
No package. Vendor the mirrored source: 27 lines, June 9 Researcher Reciprocity License v1.0.
submission.py
curl "https://kernelindex.com/api/v1/implementations/kernelbot-vectoradd-v2-515768?include=source"interfacepython
Compatibility
measured onNVIDIA A100
declared hardwareNVIDIA A100
architecturessm_80
dtypesfp16
Benchmark evidence
1 measurement across 1 GPU, fastest first.
Operation / workload
Hardware
Latency
Rank
Observed
Reported · How evidence levels are derived →
Source and license
sourceavailable
revision digestsha256:74ea6cafa815d3fe9a53902475ffe260ece15be27d8657a76148606623c0f92f
license declaredunknown
license concludedunknown
authorsWeyland Joyner
imported2026-08-15
Kernel source
submission.py27 lines
#!POPCORN leaderboard vectoradd_v2
#!POPCORN gpu A100
import torch
import triton
import triton.language as tl
@triton.jit
def vec_add_kernel(A_ptr, B_ptr, C_ptr, SIZE, BLOCK: tl.constexpr):
pid = tl.program_id(0)
offs = pid * BLOCK + tl.arange(0, BLOCK)
mask = offs < SIZE
a = tl.load(A_ptr + offs, mask=mask)
b = tl.load(B_ptr + offs, mask=mask)
tl.store(C_ptr + offs, a + b, mask=mask)
def custom_kernel(data):
A, B, C = data
SIZE = A.numel()
BLOCK = 1024
grid = (triton.cdiv(SIZE, BLOCK),)
vec_add_kernel[grid](
A.view(-1), B.view(-1), C.view(-1),
SIZE, BLOCK
)
return C
Source code from GPU Mode and the KernelBot dataset · June 9 Researcher Reciprocity License v1.0
Best evidence level for this revision: reported
JSON